@@ -8,6 +8,10 @@ from metaphor.redshift.config import RedshiftRunConfig
 
 @dataclass
 class RedshiftUsageRunConfig(RedshiftRunConfig):
+    # whether to write to dataset usage history or dataset usage aspect
+    use_history: bool = True
+
+    # Number of days of query logs to process if use_history = False, otherwise, it's locked to 1 day
     lookback_days: int = 30
 
     # Query filter to exclude certain usernames from the processing
